@@ -4,7 +4,7 @@ import abc
 from enum import Enum
 from os import PathLike
 import json
-from typing import Optional, Union, List, Any
+from typing import Optional, Union, List, Any, Tuple
 import jsonschema  # type: ignore
 
 import pandas as pd  # type: ignore
@@ -14,7 +14,7 @@ from ipyvizzu.json import RawJavaScript, RawJavaScriptEncoder
 from ipyvizzu.schema import DATA_SCHEMA
 
 
-class Animation:
+class AbstractAnimation:
     """
     An abstract class for representing animation objects
     that have `dump` and `build` methods.
@@ -42,7 +42,7 @@ class Animation:
         """
 
 
-class PlainAnimation(dict, Animation):
+class PlainAnimation(dict, AbstractAnimation):
     """
     A class for representing plain animation.
     It can build any dictionary.
@@ -69,7 +69,7 @@ class InferType(Enum):
     """An enum key-value for storing measure infer type."""
 
 
-class Data(dict, Animation):
+class Data(dict, AbstractAnimation):
     """
     A class for representing data animation.
     It can build data option of the chart.
@@ -392,6 +392,9 @@ class ConfigAttr(type):
     A metaclass class for the [Config][ipyvizzu.animation.Config] class.
     Returns a [Config][ipyvizzu.animation.Config] class with a chart preset
     if the `__getattr__` method called.
+
+    For information on all available chart presets see the
+    [Vizzu Code reference](https://lib.vizzuhq.com/0.7/reference/modules/presets/#interfaces).
     """
 
     @classmethod
@@ -404,7 +407,7 @@ class ConfigAttr(type):
         return config
 
 
-class Config(Animation, metaclass=ConfigAttr):
+class Config(AbstractAnimation, metaclass=ConfigAttr):
     """
     A class for representing config animation.
     It can build config option of the chart.
@@ -415,8 +418,11 @@ class Config(Animation, metaclass=ConfigAttr):
         Config constructor.
 
         Args:
-            data: A config animation dictionary.
-        """
+            data:
+                A config animation dictionary.
+                For information on all available config parameters see the
+                [Vizzu Code reference](https://lib.vizzuhq.com/0.7/reference/interfaces/vizzu.Config.Chart/#properties).
+        """  # pylint: disable=line-too-long
 
         self._data = data
 
@@ -432,7 +438,7 @@ class Config(Animation, metaclass=ConfigAttr):
         return {"config": self._data}
 
 
-class Style(Animation):
+class Style(AbstractAnimation):
     """
     A class for representing style animation.
     It can build style option of the chart.
@@ -443,8 +449,12 @@ class Style(Animation):
         Style constructor.
 
         Args:
-            data: A style animation dictionary.
-        """
+            data:
+                A style animation dictionary.
+                For information on all available style parameters see the [Style][styling-properties]
+                chapter or the
+                [Vizzu Code reference](https://lib.vizzuhq.com/0.7/reference/interfaces/vizzu.Styles.Chart/#properties).
+        """  # pylint: disable=line-too-long
 
         self._data = data
 
@@ -460,52 +470,123 @@ class Style(Animation):
         return {"style": self._data}
 
 
-class Snapshot(Animation):
+class Keyframe(AbstractAnimation):
     """
-    A class for representing snapshot animation.
+    A class for representing keyframe animation.
+    It can build keyframe of the chart.
+    """
+
+    def __init__(
+        self,
+        *animations: AbstractAnimation,
+        **options: Optional[Union[str, int, float, dict]],
+    ):
+        """
+        Keyframe constructor.
+
+        Args:
+            *animations:
+                List of AbstractAnimation inherited objects such as [Data][ipyvizzu.animation.Data],
+                [Config][ipyvizzu.animation.Config] and [Style][ipyvizzu.animation.Style].
+            **options: Dictionary of animation options for example `duration=1`.
+                For information on all available animation options see the
+                [Vizzu Code reference](https://lib.vizzuhq.com/0.7/reference/interfaces/vizzu.Anim.Options/#properties).
+
+        Raises:
+            ValueError: If `animations` is not set.
+            ValueError: If initialized with a `Keyframe`.
+        """  # pylint: disable=line-too-long
+
+        if not animations:
+            raise ValueError("No animation was set.")
+        if [animation for animation in animations if isinstance(animation, Keyframe)]:
+            raise ValueError("A Keyframe cannot contain a Keyframe.")
+
+        self._keyframe = {}
+        self._keyframe["target"] = AnimationMerger.merge_animations(animations).build()
+        if options:
+            self._keyframe["options"] = options
+
+    def build(self) -> dict:
+        """
+        A method for returning the keyframe animation dictionary.
+
+        Returns:
+            A dictionary that stored in the keyframe animation object.
+                It contains a `target` key whose value is the stored animation
+                and an optional `options` key whose value is the stored animation options.
+        """
+
+        return self._keyframe
+
+
+class Snapshot(AbstractAnimation):
+    """
+    A class for representing a stored chart state.
     It can build the snapshot id of the chart.
     """
 
-    def __init__(self, name: str):
+    def __init__(self, snapshot_id: str):
         """
         Snapshot constructor.
 
         Args:
-            name: A snapshot id.
+            snapshot_id: A snapshot id.
         """
 
-        self._name = name
+        self._snapshot_id = snapshot_id
 
-    def dump(self) -> str:
+    def build(self) -> str:  # type: ignore
         """
-        A method for overwriting the
-        [Animation.dump][ipyvizzu.animation.Animation.dump] method.
-        It dumps the stored snapshot id as a string.
+        A method for returning the snapshot id str.
 
         Returns:
-            An str that contains the stored snapshot id.
+            An str snapshot id that stored in the snapshot animation object.
         """
 
-        return f"'{self._name}'"
-
-    def build(self):
-        """
-        A method for preventing to merge [Snapshot][ipyvizzu.animation.Snapshot]
-        with other animations.
-
-        Raises:
-            NotImplementedError: If the [build][ipyvizzu.animation.Snapshot.build] method
-                has been called, because [Snapshot][ipyvizzu.animation.Snapshot]
-                cannot be merged with other animations.
-        """
-
-        raise NotImplementedError("Snapshot cannot be merged with other animations")
+        return self._snapshot_id
 
 
-class AnimationMerger(dict, Animation):
+class Animation(Snapshot):
+    """
+    A class for representing a stored animation.
+    It can build the snapshot id of the animation.
+    """
+
+
+class AnimationMerger(AbstractAnimation):
     """A class for merging different types of animations."""
 
-    def merge(self, animation: Animation) -> None:
+    def __init__(self):
+        """AnimationMerger constructor."""
+
+        self._dict = {}
+        self._list = []
+
+    @classmethod
+    def merge_animations(
+        cls, animations: Tuple[AbstractAnimation, ...]
+    ) -> AbstractAnimation:
+        """
+        A class method for merging animations.
+
+        Args:
+            animations: List of `AbstractAnimation` inherited objects.
+
+        Returns:
+            An `AnimationMerger` class with the merged animations.
+        """
+
+        if len(animations) == 1 and not isinstance(animations[0], Keyframe):
+            return animations[0]
+
+        merger = cls()
+        for animation in animations:
+            merger.merge(animation)
+
+        return merger
+
+    def merge(self, animation: AbstractAnimation) -> None:
         """
         A method for merging an animation with the previously merged animations.
 
@@ -514,29 +595,44 @@ class AnimationMerger(dict, Animation):
 
         Raises:
             ValueError: If the type of an animation is already merged.
+            ValueError: If `Keyframe` is merged with different type of animation.
         """
 
-        data = self._validate(animation)
-        self.update(data)
+        if isinstance(animation, Keyframe):
+            if self._dict:
+                raise ValueError("Keyframe cannot be merged with other animations.")
+            data = animation.build()
+            self._list.append(data)
+        else:
+            if self._list:
+                raise ValueError("Keyframe cannot be merged with other animations.")
+            data = self._validate(animation)
+            self._dict.update(data)
 
-    def _validate(self, animation: Animation) -> dict:
+    def _validate(self, animation: AbstractAnimation) -> dict:
+        if isinstance(animation, Snapshot):
+            raise ValueError("Snapshot cannot be merged with other animations.")
         data = animation.build()
-        common_keys = set(data).intersection(self)
+        common_keys = set(data).intersection(self._dict)
 
         if common_keys:
-            raise ValueError(f"Animation is already merged: {common_keys}")
+            raise ValueError(f"{common_keys} is already merged.")
 
         return data
 
-    def build(self) -> dict:
+    def build(self) -> Union[dict, list]:  # type: ignore
         """
-        A method for returning a merged dictionary from different types of animations.
+        A method for returning a merged list of `Keyframes`
+        or a merged dictionary from different types of animations.
 
         Returns:
-            A merged dictionary from
+            A merged list of [Keyframes][ipyvizzu.animation.Keyframe] or
+                a merged dictionary from
                 [Data][ipyvizzu.animation.Data],
                 [Config][ipyvizzu.animation.Config] and
                 [Style][ipyvizzu.animation.Style] animations.
         """
 
-        return self
+        if self._dict:
+            return self._dict
+        return self._list
