@@ -2,12 +2,13 @@
 
 import pkgutil
 import uuid
-from typing import List, Optional, Union, Tuple
+from typing import List, Optional, Union
 
 from IPython.display import display_javascript  # type: ignore
 from IPython import get_ipython  # type: ignore
 
-from ipyvizzu.animation import Animation, Snapshot, AnimationMerger
+from ipyvizzu.animation import AbstractAnimation, Snapshot, AnimationMerger
+from ipyvizzu.animationcontrol import AnimationControl
 from ipyvizzu.method import Animate, Feature, Store, EventOn, EventOff, Log
 from ipyvizzu.template import ChartProperty, DisplayTarget, DisplayTemplate
 from ipyvizzu.event import EventHandler
@@ -16,15 +17,17 @@ from ipyvizzu.event import EventHandler
 class Chart:
     """A class for representing a wrapper over Vizzu chart."""
 
+    # pylint: disable=too-many-instance-attributes
+
     VIZZU: str = "https://cdn.jsdelivr.net/npm/vizzu@0.7/dist/vizzu.min.js"
     """A variable for storing the default url of vizzu package."""
 
     def __init__(
         self,
-        vizzu: Optional[str] = VIZZU,
-        width: Optional[str] = "800px",
-        height: Optional[str] = "480px",
-        display: Optional[Union[DisplayTarget, str]] = DisplayTarget.ACTUAL,
+        vizzu: str = VIZZU,
+        width: str = "800px",
+        height: str = "480px",
+        display: Union[DisplayTarget, str] = DisplayTarget.ACTUAL,
     ):
         """
         Chart constructor.
@@ -36,29 +39,19 @@ class Chart:
             display: The display behaviour of the chart.
         """
 
-        self._chart_id = uuid.uuid4().hex[:7]
+        self._chart_id: str = uuid.uuid4().hex[:7]
 
-        self._display_target = DisplayTarget(display)
+        self._vizzu: str = vizzu
+        self._width: str = width
+        self._height: str = height
+
+        self._display_target: DisplayTarget = DisplayTarget(display)
         self._calls: List[str] = []
-        self._showed = False
+        self._last_anim: Optional[str] = None
+        self._showed: bool = False
 
-        self._scroll_into_view = False
-
-        ipyvizzurawjs = pkgutil.get_data(__name__, "templates/ipyvizzu.js")
-        ipyvizzujs = ipyvizzurawjs.decode("utf-8")  # type: ignore
-        self._display(DisplayTemplate.IPYVIZZUJS.format(ipyvizzujs=ipyvizzujs))
-
-        self._display(
-            DisplayTemplate.INIT.format(
-                chart_id=self._chart_id,
-                vizzu=vizzu,
-                div_width=width,
-                div_height=height,
-            )
-        )
-
-        if self._display_target != DisplayTarget.MANUAL:
-            self._register_events()
+        self._initialized: bool = False
+        self._scroll_into_view: bool = False
 
     @staticmethod
     def _register_events() -> None:
@@ -85,17 +78,56 @@ class Chart:
     def scroll_into_view(self, scroll_into_view: Optional[bool]):
         self._scroll_into_view = bool(scroll_into_view)
 
+    @property
+    def control(self) -> AnimationControl:
+        """
+        A property for returning a control object of the last animation.
+
+        Raises:
+            AssertionError: If called before any animation plays.
+
+        Returns:
+            The control object of the last animation.
+        """
+        assert self._last_anim, "must be used after an animation."
+        return AnimationControl(self._chart_id, self._last_anim, self._display)
+
+    def initializing(self) -> None:
+        """A method for initializing the chart."""
+
+        if not self._initialized:
+            self._initialized = True
+            ipyvizzurawjs = pkgutil.get_data(__name__, "templates/ipyvizzu.js")
+            ipyvizzujs = ipyvizzurawjs.decode("utf-8")  # type: ignore
+            self._display(DisplayTemplate.IPYVIZZUJS.format(ipyvizzujs=ipyvizzujs))
+
+            if self._display_target != DisplayTarget.MANUAL:
+                Chart._register_events()
+
+            self._display(
+                DisplayTemplate.INIT.format(
+                    chart_id=self._chart_id,
+                    vizzu=self._vizzu,
+                    div_width=self._width,
+                    div_height=self._height,
+                )
+            )
+
     def animate(
-        self, *animations: Animation, **options: Optional[Union[str, int, float, dict]]
+        self,
+        *animations: AbstractAnimation,
+        **options: Optional[Union[str, int, float, dict]],
     ) -> None:
         """
         A method for changing the state of the chart.
 
         Args:
             *animations:
-                List of Animation objects such as [Data][ipyvizzu.animation.Data],
+                List of AbstractAnimation inherited objects such as [Data][ipyvizzu.animation.Data],
                 [Config][ipyvizzu.animation.Config] and [Style][ipyvizzu.animation.Style].
             **options: Dictionary of animation options for example `duration=1`.
+                For information on all available animation options see the
+                [Vizzu Code reference](https://lib.vizzuhq.com/0.7/reference/interfaces/vizzu.Anim.Options/#properties).
 
         Raises:
             ValueError: If `animations` is not set.
@@ -104,49 +136,41 @@ class Chart:
             Reset the chart styles:
 
                 chart.animate(Style(None))
-        """
+        """  # pylint: disable=line-too-long
 
         if not animations:
             raise ValueError("No animation was set.")
 
-        animation = self._merge_animations(animations)
+        animation = AnimationMerger.merge_animations(animations)
         animate = Animate(animation, options)
 
+        self._last_anim = uuid.uuid4().hex[:7]
         self._display(
             DisplayTemplate.ANIMATE.format(
                 display_target=self._display_target.value,
                 chart_id=self._chart_id,
+                anim_id=self._last_anim,
                 scroll=str(self._scroll_into_view).lower(),
                 **animate.dump(),
             )
         )
 
-    @staticmethod
-    def _merge_animations(
-        animations: Tuple[Animation, ...],
-    ) -> Union[Animation, AnimationMerger]:
-        if len(animations) == 1:
-            return animations[0]
-
-        merger = AnimationMerger()
-        for animation in animations:
-            merger.merge(animation)
-
-        return merger
-
     def feature(self, name: str, enabled: bool) -> None:
         """
         A method for turning on/off features of the chart.
 
         Args:
-            name: The name of the chart feature.
+            name:
+                The name of the chart feature.
+                For information on all available features see the
+                [Vizzu Code reference](https://lib.vizzuhq.com/0.7/reference/modules/vizzu/#feature).
             enabled: The new state of the chart feature.
 
         Example:
             Turn on `tooltip` of the chart:
 
                 chart.feature("tooltip", True)
-        """
+        """  # pylint: disable=line-too-long
 
         self._display(
             DisplayTemplate.FEATURE.format(
@@ -160,7 +184,7 @@ class Chart:
         A method for saving and storing the actual state of the chart.
 
         Returns:
-            A snapshot animation object wich stores the actual state of the chart.
+            A Snapshot object wich stores the actual state of the chart.
 
         Example:
             Save and restore the actual state of the chart:
@@ -185,7 +209,10 @@ class Chart:
         A method for creating and turning on an event handler.
 
         Args:
-            event: The type of the event.
+            event:
+                The type of the event.
+                For information on all available events see the
+                [Vizzu Code reference](https://lib.vizzuhq.com/0.7/reference/modules/vizzu.Event/#type).
             handler: The JavaScript method of the event.
 
         Returns:
@@ -196,7 +223,7 @@ class Chart:
             when someone clicks on the chart:
 
                 handler = chart.on("click", "alert(JSON.stringify(event.data));")
-        """
+        """  # pylint: disable=line-too-long
 
         event_handler = EventHandler(event, handler)
         self._display(
@@ -255,6 +282,8 @@ class Chart:
         ), "chart._repr_html_() can be used with display=DisplayTarget.MANUAL only"
         assert not self._showed, "cannot be used after chart displayed."
         self._showed = True
+        if not self._initialized:
+            return ""
         html_id = uuid.uuid4().hex[:7]
         script = (
             self._calls[0]
@@ -286,6 +315,8 @@ class Chart:
         self._showed = True
 
     def _display(self, javascript: str) -> None:
+        if not self._initialized:
+            self.initializing()
         if self._display_target != DisplayTarget.MANUAL:
             display_javascript(
                 javascript,
