@@ -6,7 +6,16 @@ import unittest.mock
 from typing import Callable
 
 from tests.normalizer import Normalizer
-from tests import Chart, ChartProperty, Data, Config, Snapshot, Style, EventHandler
+from tests import (
+    Chart,
+    ChartProperty,
+    Data,
+    Config,
+    Snapshot,
+    Style,
+    EventHandler,
+    Animation,
+)
 
 
 class TestChart(unittest.TestCase, abc.ABC):
@@ -25,6 +34,7 @@ class TestChart(unittest.TestCase, abc.ABC):
         self.patch = unittest.mock.patch(self.mock)
         self.trash = self.patch.start()
         self.chart = Chart()
+        self.chart.initializing()
 
     def tearDown(self) -> None:
         self.patch.stop()
@@ -56,7 +66,8 @@ class TestChartInit(TestChart):
         """
 
         with unittest.mock.patch(self.mock) as output:
-            Chart()
+            chart = Chart()
+            chart.initializing()
             self.assertEqual(
                 self.normalizer.normalize_output(output, 1),
                 "window.ipyvizzu.createChart("
@@ -75,7 +86,10 @@ class TestChartInit(TestChart):
         """
 
         with unittest.mock.patch(self.mock) as output:
-            Chart(vizzu="https://cdn.jsdelivr.net/npm/vizzu@0.4.1/dist/vizzu.min.js")
+            chart = Chart(
+                vizzu="https://cdn.jsdelivr.net/npm/vizzu@0.4.1/dist/vizzu.min.js"
+            )
+            chart.initializing()
             self.assertEqual(
                 self.normalizer.normalize_output(output, 1),
                 "window.ipyvizzu.createChart("
@@ -94,7 +108,8 @@ class TestChartInit(TestChart):
         """
 
         with unittest.mock.patch(self.mock) as output:
-            Chart(width="400px", height="240px")
+            chart = Chart(width="400px", height="240px")
+            chart.initializing()
             self.assertEqual(
                 self.normalizer.normalize_output(output, 1),
                 "window.ipyvizzu.createChart("
@@ -123,12 +138,12 @@ class TestChartInit(TestChart):
             AssertionError: If the normalized output is not correct.
         """
 
-        self.chart = Chart(display="begin")
         with unittest.mock.patch(self.mock) as output:
-            self.chart.animate(Snapshot("abc1234"))
+            chart = Chart(display="begin")
+            chart.animate(Snapshot("abc1234"))
             self.assertEqual(
-                self.normalizer.normalize_output(output),
-                "window.ipyvizzu.animate(element, id, 'begin', false, "
+                self.normalizer.normalize_output(output, 2),
+                "window.ipyvizzu.animate(element, id, id, 'begin', false, "
                 + "lib => { return id }, "
                 + "undefined);",
             )
@@ -141,12 +156,12 @@ class TestChartInit(TestChart):
             AssertionError: If the normalized output is not correct.
         """
 
-        self.chart = Chart(display="actual")
         with unittest.mock.patch(self.mock) as output:
-            self.chart.animate(Snapshot("abc1234"))
+            chart = Chart(display="actual")
+            chart.animate(Snapshot("abc1234"))
             self.assertEqual(
-                self.normalizer.normalize_output(output),
-                "window.ipyvizzu.animate(element, id, 'actual', false, "
+                self.normalizer.normalize_output(output, 2),
+                "window.ipyvizzu.animate(element, id, id, 'actual', false, "
                 + "lib => { return id }, "
                 + "undefined);",
             )
@@ -159,12 +174,32 @@ class TestChartInit(TestChart):
             AssertionError: If the normalized output is not correct.
         """
 
-        self.chart = Chart(display="end")
         with unittest.mock.patch(self.mock) as output:
+            chart = Chart(display="end")
+            chart.animate(Snapshot("abc1234"))
+            self.assertEqual(
+                self.normalizer.normalize_output(output, 2),
+                "window.ipyvizzu.animate(element, id, id, 'end', false, "
+                + "lib => { return id }, "
+                + "undefined);",
+            )
+
+    def test_manual_init(self) -> None:
+        """
+        A method for testing multiple manual init.
+
+        Raises:
+            AssertionError: If the normalized output is not correct.
+        """
+
+        with unittest.mock.patch(self.mock) as output:
+            self.chart.initializing()
+            self.chart.initializing()
+            self.chart.initializing()
             self.chart.animate(Snapshot("abc1234"))
             self.assertEqual(
                 self.normalizer.normalize_output(output),
-                "window.ipyvizzu.animate(element, id, 'end', false, "
+                "window.ipyvizzu.animate(element, id, id, 'actual', false, "
                 + "lib => { return id }, "
                 + "undefined);",
             )
@@ -200,9 +235,10 @@ class TestChartInit(TestChart):
         get_ipython_mock = "ipyvizzu.chart.get_ipython"
         with unittest.mock.patch(get_ipython_mock, return_value=IPy()):
             with unittest.mock.patch(self.mock) as output:
-                Chart()
+                chart = Chart()
+                chart.initializing()
                 self.assertEqual(
-                    self.normalizer.normalize_output(output, 2),
+                    self.normalizer.normalize_output(output, 1, 2),
                     "if (window.IpyVizzu) { window.IpyVizzu.clearInhibitScroll(element); }",
                 )
 
@@ -254,7 +290,7 @@ class TestChartMethods(TestChart):
             self.chart.animate(data)
             self.assertEqual(
                 self.normalizer.normalize_output(output),
-                "window.ipyvizzu.animate(element, id, 'actual', false, "
+                "window.ipyvizzu.animate(element, id, id, 'actual', false, "
                 + 'lib => { return {"data": {"records": [["Rock", "Hard", 96]]}} }, '
                 + "undefined);",
             )
@@ -274,7 +310,7 @@ class TestChartMethods(TestChart):
             self.chart.animate(data, duration="500ms")
             self.assertEqual(
                 self.normalizer.normalize_output(output),
-                "window.ipyvizzu.animate(element, id, 'actual', false, "
+                "window.ipyvizzu.animate(element, id, id, 'actual', false, "
                 + 'lib => { return {"data": {"records": [["Rock", "Hard", 96]]}} }, '
                 + '{"duration": "500ms"});',
             )
@@ -293,7 +329,7 @@ class TestChartMethods(TestChart):
             self.chart.animate(snapshot)
             self.assertEqual(
                 self.normalizer.normalize_output(output),
-                "window.ipyvizzu.animate(element, id, 'actual', false, "
+                "window.ipyvizzu.animate(element, id, id, 'actual', false, "
                 + "lib => { return id }, "
                 + "undefined);",
             )
@@ -312,7 +348,26 @@ class TestChartMethods(TestChart):
             self.chart.animate(snapshot, duration="500ms")
             self.assertEqual(
                 self.normalizer.normalize_output(output),
-                "window.ipyvizzu.animate(element, id, 'actual', false, "
+                "window.ipyvizzu.animate(element, id, id, 'actual', false, "
+                + "lib => { return id }, "
+                + '{"duration": "500ms"});',
+            )
+
+    def test_animate_stored_animation_chart_target(self) -> None:
+        """
+        A method for testing Chart.animate method.
+        It tests with Animation chart target.
+
+        Raises:
+            AssertionError: If the normalized output is not correct.
+        """
+
+        with unittest.mock.patch(self.mock) as output:
+            animation = Animation("abc1234")
+            self.chart.animate(animation, duration="500ms")
+            self.assertEqual(
+                self.normalizer.normalize_output(output),
+                "window.ipyvizzu.animate(element, id, id, 'actual', false, "
                 + "lib => { return id }, "
                 + '{"duration": "500ms"});',
             )
@@ -334,7 +389,7 @@ class TestChartMethods(TestChart):
             self.chart.animate(data, config, style)
             self.assertEqual(
                 self.normalizer.normalize_output(output),
-                "window.ipyvizzu.animate(element, id, 'actual', false, "
+                "window.ipyvizzu.animate(element, id, id, 'actual', false, "
                 + 'lib => { return {"data": {"records": [["Rock", "Hard", 96]]}, '
                 + '"config": {"channels": {"label": {"attach": ["Popularity"]}}}, '
                 + '"style": {"title": {"backgroundColor": "#A0A0A0"}}} }, '
@@ -358,7 +413,7 @@ class TestChartMethods(TestChart):
             self.chart.animate(data, config, style, duration="500ms")
             self.assertEqual(
                 self.normalizer.normalize_output(output),
-                "window.ipyvizzu.animate(element, id, 'actual', false, "
+                "window.ipyvizzu.animate(element, id, id, 'actual', false, "
                 + 'lib => { return {"data": {"records": [["Rock", "Hard", 96]]}, '
                 + '"config": {"channels": {"label": {"attach": ["Popularity"]}}}, '
                 + '"style": {"title": {"backgroundColor": "#A0A0A0"}}} }, '
@@ -388,7 +443,7 @@ class TestChartMethods(TestChart):
         It raises an error if has ben called with multiple chart targets and Snapshot chart target.
 
         Raises:
-            AssertionError: If NotImplementedError is not occurred.
+            AssertionError: If ValueError is not occurred.
         """
 
         data = Data()
@@ -396,7 +451,7 @@ class TestChartMethods(TestChart):
         config = Config({"channels": {"label": {"attach": ["Popularity"]}}})
         style = Style({"title": {"backgroundColor": "#A0A0A0"}})
         snapshot = Snapshot("abc1234")
-        with self.assertRaises(NotImplementedError):
+        with self.assertRaises(ValueError):
             self.chart.animate(data, config, style, snapshot)
 
     def test_animate_more_calls(self) -> None:
@@ -418,12 +473,12 @@ class TestChartMethods(TestChart):
             self.chart.animate(config2)
             self.assertEqual(
                 self.normalizer.normalize_output(output),
-                "window.ipyvizzu.animate(element, id, 'actual', false, "
+                "window.ipyvizzu.animate(element, id, id, 'actual', false, "
                 + 'lib => { return {"data": {"records": [["Rock", "Hard", 96]]}, '
                 + '"config": {"channels": {"label": {"attach": ["Popularity"]}}}, '
                 + '"style": {"title": {"backgroundColor": "#A0A0A0"}}} }, '
                 + "undefined);\n"
-                + "window.ipyvizzu.animate(element, id, 'actual', false, "
+                + "window.ipyvizzu.animate(element, id, id, 'actual', false, "
                 + 'lib => { return {"config": {"title": "Test"}} }, '
                 + "undefined);",
             )
@@ -445,7 +500,8 @@ class TestChartMethods(TestChart):
             self.chart.animate(data)
             self.assertEqual(
                 self.normalizer.normalize_output(output),
-                f"window.ipyvizzu.animate(element, id, 'actual', {str(scroll_into_view).lower()}, "
+                "window.ipyvizzu.animate("
+                + f"element, id, id, 'actual', {str(scroll_into_view).lower()}, "
                 + 'lib => { return {"data": {"records": [["Rock", "Hard", 96]]}} }, '
                 + "undefined);",
             )
@@ -612,22 +668,22 @@ class TestChartDisplay(TestChart):
             AssertionError: If the normalized output is not correct.
         """
 
-        self.chart = Chart(display="manual")
         display_mock = "ipyvizzu.Chart._display"
         with unittest.mock.patch(display_mock) as output:
-            self.chart.animate(Snapshot("abc1234"))
+            chart = Chart(display="manual")
+            chart.animate(Snapshot("abc1234"))
             self.assertEqual(
-                self.chart._showed,  # pylint: disable=protected-access
+                chart._showed,  # pylint: disable=protected-access
                 False,
             )
-            self.chart._repr_html_()  # pylint: disable=protected-access
+            chart._repr_html_()  # pylint: disable=protected-access
             self.assertEqual(
-                self.chart._showed,  # pylint: disable=protected-access
+                chart._showed,  # pylint: disable=protected-access
                 True,
             )
             self.assertEqual(
                 self.normalizer.normalize_output(output),
-                "window.ipyvizzu.animate(element, id, 'manual', false, "
+                "window.ipyvizzu.animate(element, id, id, 'manual', false, "
                 + "lib => { return id }, "
                 + "undefined);",
             )
@@ -655,7 +711,7 @@ class TestChartDisplay(TestChart):
             )
             self.assertEqual(
                 self.normalizer.normalize_output(output),
-                "window.ipyvizzu.animate(element, id, 'manual', false, "
+                "window.ipyvizzu.animate(element, id, id, 'manual', false, "
                 + "lib => { return id }, "
                 + "undefined);",
             )
